FarConfig class

Constructors

FarConfig({bool? enable, String? targetName, String? appName, String? bundleName, String? bundleId, Map<String, dynamic>? bundleIds, String? copyright, String? package})
FarConfig.fromJson(Map<String, dynamic> json)
factory
FarConfig.fromRawJson(String str)
factory

Properties

appName String?
getter/setter pair
bundleId String?
getter/setter pair
bundleIds Map<String, dynamic>?
getter/setter pair
bundleName String?
getter/setter pair
getter/setter pair
enable bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
package String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited