FARPlatformAndroid class

Constructors

FARPlatformAndroid()

Properties

currentDirPath String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
platform FARPlatform
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findCommonPath(String str1, String str2) String
listAllFiles(Directory dir) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processAndroidCodeFileDirectory({required String currentDirPath, required String newPackage}) Future<void>
processBuildGradleBundleId({required String bundleId}) → void
run({required String dirPath, required FarConfig farConfig}) Future<void>
运行 Android 工程的替换任务
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited