FARPlatformAndroidManifest class

Constructors

FARPlatformAndroidManifest(String dirPath, String newAppName, String newPackage)

Properties

debugAndroidManifestFile File
getter/setter pair
dirPath String
final
hashCode int
The hash code for this object.
no setterinherited
mainAndroidManifestFile File
getter/setter pair
newAppName String
final
newPackage String
final
profileAndroidManifestFile File
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valuesDir Directory
getter/setter pair

Methods

getDocStringValue({required XmlDocument doc, required String name, required String attributeName, required String targetKey}) String
getValueDirFile({required List<String> names, required List<String> extensions}) List<File>
getValuesDirFileStringValue({required String attributeName, required String targetKey}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDocStringValue({required XmlDocument doc, required String name, required String attributeName, required String targetKey, required String targetValue, bool autoFill = false}) → void
setValuesDirFileStringValue({required String attributeName, required String targetKey, required String targetValue}) → void
toString() String
A string representation of this object.
inherited
update() Future<void>
修改 AndroidManifest.xml 中的 android:label
updateManifestAppName(XmlDocument doc) → XmlDocument
updateManifestPackage(XmlDocument doc) → XmlDocument

Operators

operator ==(Object other) bool
The equality operator.
inherited