DarwinUtil class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
findTargetBuildConfiguration(dynamic element, String uuid)
→ dynamic
-
-
findXCConfigurationList(dynamic element, String targetName)
→ dynamic
-
-
getProjectBuildConfigurationUuids(Pbxproj project, String targetName)
→ List<String>
-
-
updatePbxprojBundleId({required String dir, required String platform, required String targetName, required List<DarwinBundleIDSettings> bundleIdSettings})
→ Future
-
-
updatePlistName({required String dir, required String platformName, required String targetName, required String bundleName, required String bundleDisplayName})
→ void
-