LogUtil class

Properties

hashCode int
The hash code for this object.
no setterinherited
logs List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLog(String text, {bool record = true, bool newLine = false}) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance LogUtil
final