FARPlatformMacOS class

Constructors

FARPlatformMacOS()

Properties

bundleDisplayName String
no setter
bundleName String
no setter
config FarConfig
getter/setter pair
no setter
currentDirPath String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
platform FARPlatform
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetName String
no setter

Methods

getBundleIDSettings() List<DarwinBundleIDSettings>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renameConfigsAppInfoValues() Future<void>
renamePlist() → void
run({required String dirPath, required FarConfig farConfig}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited