FileUtil class
Constructors
- FileUtil()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
copyDirectory(
Directory source, Directory destination) → void -
copyFile(
String sourcePath, String targetPath) → Future< void> -
createDirectoryIfNotExist(
String directoryPath) → Future< void> - 如果目录不存在,则创建它。
-
getFilePathEntityType(
String path) → Future< FileSystemEntityType> -
listFilesByExtensions(
String directoryPath, List< String> extensions) → List<String> -
removeEmptyDir(
{required Directory dir}) → Future< void> -
renameFile(
String filePath, String newFileName) → Future< void>